Tunnuksen rekisteröinti - Riemurasia
Description: Klikkaa itsesi Riemurasian villiin maailmaan!

Etusivu
Käyttäjät
Jylppy-Galleria
Rasiatube
Pelit
Linkit
RasiaTV
Goodgame Empire
Lisää..
Teema:
Kirjaudu

JYLPPY-GALLERIA ETUSIVU

KUVAT

Uusimmat kuvat

Katsotuimmat kuvat

Suosituimmat kuvat

Puhutuimmat kuvat

VIDEOT

Uusimmat videot

Katsotuimmat videot

Suosituimmat videot

Puhutuimmat videot

TEKSTIT

Uusimmat tekstit

Katsotuimmat tekstit

Suosituimmat tekstit

Puhutuimmat tekstit

ÄÄNET

Uusimmat äänet

Katsotuimmat äänet

Suosituimmat äänet

Puhutuimmat äänet

FLASH

Uusimmat flashit

Katsotuimmat flashit

Suosituimmat flashit

Puhutuimmat flashit

SELAA MEDIOITA

HAKUKONE

HYLÄTYT

LISÄÄ MEDIA

KULTAMUNA TARKASTUS

RASIATUBE
ETUSIVU

VIDEOT

Uusimmat videot

Katsotuimmat videot

Suosituimmat videot

Puhutuimmat videot

SELAA VIDEOITA

HAKUKONE

LISÄÄ VIDEO

LINKIT
ETUSIVU

LINKIT

Uusimmat linkit

Katsotuimmat linkit

Suosituimmat linkit

Puhutuimmat linkit

SELAA LINKKEJÄ

HAKUKONE

LISÄÄ LINKKI

PELIT
ETUSIVU

PELIT

Uusimmat pelit

Pelatuimmat pelit

Suosituimmat pelit

Puhutuimmat pelit

SELAA PELEJÄ

HAKUKONE

LISÄÄ PELI

Webcam-keskustelu

Palaute ylläpidolle

Mainostus

1

Riemurasian kansainvälistyminen ja Flexvee yhteistyö
5.12.2014: Jylppy69 kirjoitti

Tarkoitus on julkaista Riemurasiasta englanninkielinen versio kansainvälisille markkinoille vuoden 2015 aikana, tämä ei kuitenkaan tarkoita sitä, että koko Riemurasia suomenkielisenä palveluna lopetetaan vaan rinnalle tuodaan eri nimellä toimiva ja kansainvälisille markkinoille suunnattu sivusto.
Kaikki tutut ja turvalliset Riemurasian palvelut ja toiminnot tulevat olevaan saatavilla samalla tavalla kuin ennenkin ja kansainvälinen toiminta voi mahdollistaa uusia huikeita asioita myös Riemurasian kehittämiseen jotka eivät pelkästään suomen mittapuulla olisi olleet mahdollisia, vuodesta 2015 tulee taatusti jännittävä kaikinpuolin ja pyrimme tekemään parhaamme että viihdytte palvelumme parissa vielä pitkän ajan.
Neonella Oy on tullut kanssamme mukaan strategiseen yhteistyöhön ja keräämme yhdessä rahoitusta.
Tarkoitus on tehdä syventävää yhteistyötä kummankin palvelun kehittämiseksi ja tuoda myös Riemurasian käyttäjiä mukaan Flexveen palvelujen pariin.
Tällä hetkellä Riemurasia ja Flexvee (Neonella Oy) kerää yhteisrahoitusta FundedByMe joukkorahoitusalustan kautta niin, että sijoittaja saa jomman kumman yrityksen osakkeita haluamansa määrän ja saa sijoittamansa rahan myöhemmin takaisin mahdollisten osinkojen kautta.
Kommenteissa liikkuneisiin spekulointeihin vastauksena siis, että mistään pyramidihuijauksesta ei ole kyse ja yhteistyöllä ei ole mitään negatiivisia vaikutuksia Riemurasiaan tulevaisuudessa. :)
Neonella ei myöskään puutu Riemurasian sisältöön, kommentteihin sensuroimalla tai poistamalla medioita.

#### Mikä on Flexvee?

Flexvee on suomalaisen Neonella Oy:n kehittämä markkinointiin ja viihdesisältöön keskittynyt liiketoimintakonsepti. Sen tekninen alusta mahdollistaa vuorovaikutteisuuden sekä tv-ohjelmissa että videoissa ja palkitsee osallistumisesta. Lisäksi Flexvee mahdollistaa rahaliikenteen interaktiivisen sisällön yhteydessä. Flexvee-järjestelmää voidaan käyttää myös perinteisen online-markkinoinnin yhteydessä, kuten esimerkiksi bannereissa. Flexvee on ainutlaatuinen tapa tehdä liiketoimintaa, eikä markkinoilla ole samanlaisella konseptilla toimivaa kilpailijaa.
FundedByMe kampanja: https://www.fundedbyme.com/fi/campaign/5117/enjoy-flexvee-and-earn-bitcoins/?type=e&language=secondary
Flexvee: http://www.flexvee.fi/

# LUO TUNNUS RIEMURASIAAN

## RIEMURASIA ON ENEMMÄN KUIN VIIHDEPORTAALI

Riemurasia koostuu pääosin neljästä osiosta. Jylppy-Galleriasta, joka sisältää noin 99328 hulvatonta mediatiedostoa, kuten ajankohtaisempia kuvia, videoita, vitsejä sekä äänitiedostoja. Linkit -osiosta, joka sisältää tuhansia linkkejä mielenkiintoiseen sisältöön, sekä Pelit -osiosta, joka sisältää monia eri nettipelejä ajankuluksi. Rasiatube -osio kerää eri palveluiden (YouTube, Google, Dailymotion, Liveleak, Vimeo) parhaimmat videot yhteen osioon.

## TILAA KULTAMUNA JA VÄLTÄ MAINOKSET

Kultamuna on tarkoitettu niille, jotka haluavat ottaa enemmän irti Riemurasiasta. Maksullinen Kultamuna-ominaisuus pitää sisällään tällä hetkellä 10 lisäominaisuutta, kuten mainoksien piilottamisen.

### VIRHEITÄ LOMAKKEESSA!

Nimimerkki

*

Salasana

*

Salasana uudelleen

*

Sukupuoli

*

Asuinpaikka

*

Syntymäaika

*

Matkapuhelinnumero

Sähköpostiosoite

*

Tarkiste: Minkä värinen on paloauto?

*

Haluan vastaanottaa Riemurasian yhteistyökumppaneilta sähköistä viestintää.Lue tästä millaisesta viestinnästä on kyse. Palvelun käyttöehdot löytyvät tästä.

Haluan vastaanottaa Riemurasian ylläpidolta tiedotteita.

Riemurasian rekisteselosteen voit lukea tästä.

## SÄHKÖINEN VIESTINTÄ

Liittymällä Riemurasian sähköisen viestinnän palveluun saat kutsuja tapahtumiin, keikoille, messuille ja näyttelyihin. Pääset mukaan myös uusien tuotteiden kokeiluun, uutuusautojen koeajoille tai sinua kiinnostavien tuotteiden ja palveluiden esittelyihin. Unohtamatta tietenkään Riemurasian käyttäjille suunnattuja erikoistarjouksia mm. elektroniikkatuotteista. Saat max. 2 viestiä per kuukausi.

## KÄYTTÖEHDOT

Riemurasia.net- palvelun käyttäjänä olen tietoinen siitä, että henkilötietojani (nimi, puhelinnumero, sähköposti, syntymäaika, sukupuoli, asuinpaikka) saatetaan kerätä Riemurasia.net- palvelun käytön yhteydessä. Annan suostumukseni Riemurasia.net- palvelun yhteydessä luovuttamieni henkilötietojeni käsittelyn osalta seuraavaan:

a) Riemurasia Oy:llä on oikeus käyttää Riemurasia- palvelun yhteydessä luovuttamiani henkilötietojani tiedottamiseen ja markkinointiin Riemurasian käyttäjille soveltuvista Riemurasian ja yhteistyökumppaneiden tuotteista, palveluista, tapahtumista ja muista uutisista sähköisessä muodossa matkapuhelimeen tai sähköpostiin.

b) Riemurasia Oy:llä on oikeus vapaasti siirtää ja luovuttaa Riemurasia- palvelun yhteydessä luovuttamiani henkilötietoja kolmannelle osapuolelle Euroopan unionin (EU) alueella sekä Euroopan talousalueella (ETA); ja

c) Tällä suostumuksella vahvistan myös tutustuneeni Riemurasia Oy:n henkilötietojen suojaperiaatteisiin sekä Riemurasia.net- palvelun käyttöehtoihin, joissa on tarkemmin kuvattu miten henkilötietojani kerätään ja mihin tarkoituksiin Riemurasia Oy henkilötietojani käyttää.

## REKISTERISELOSTE

Riemurasian rekisteriseloste:
1. - 2. Rekisterin pitäjä ja rekisteriasioista vastaava
Riemurasia Oy, Y-tunnus: 1909504-6, sähköposti:
3. Rekisterin nimi
Riemurasian käyttäjätietokanta
4. Rekisterin käyttötarkoitus
Henkilötietoja käsitellään henkilötietolain sallimissa ja velvoittamissa rajoissa käyttäjäsuhteen hallintaan, analysointiin, tilastointiin sekä tietopalveluiden tuottamiseen, tarjoamiseen ja kehittämiseen.
5. Rekisterin tietosisältö
Pakolliset tiedot:
Nimimerkki
Salasana
Sukupuoli
Asuinpaikka
Syntymäaika
Sähköpostiosoite
Vapaaehtoiset tiedot:
Nimi
Puhelinnumero
Kotisivun osoite
6. Säännönmukaiset tietolähteet
Rekisteröidyt ovat luovuttaneet tiedot itse omalla suostumuksellaan.
7. Säännönmukaiset tietojen luovutukset ja tietojen siirto EU:n tai Euroopan talousalueen ulkopuolelle
Rekisteriin annetut tiedot näkyvät sivustolla salasanaa lukuun ottamatta sivuston luonteen vuoksi. Luovuttaessaan tiedot Riemurasialle rekisteröity suostuu siihen, että kyseiset tiedot näkyvät muille sivuston käyttäjille. Rekisteröidyillä on mahdollisuus muuttaa ja poistaa ja piilottaa tietoja halutessaan. Tietoja ei luovuteta kolmansille osapuolille EU:n ja ETA:n sisällä eikä ulkopuolella.
8. Rekisterin suojauksen periaatteet
Jokaisella rekisteröityneellä on käyttöoikeus rekisteriin hänelle myönnetyllä käyttäjätunnuksella. Käyttäjätunnuksella ei kuitenkaan pääse näkemään eikä muuttamaan muita salaisia tietoja kuin rekisteröidyn itsensä tietoja.

###### REKISTERÖITYNEITÄ KÄYTTÄJIÄ

501,341

###### VIERAILIJOITA VIIME VIIKOLLA

534

###### MEDIAA YHTEENSÄ

141,436

###### YHTEISÖT

1,400